<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Ime_programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Uporaba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>Add New Application</source>
        <translation>Dodaj novu aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Command</source>
        <translation>Naredba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Add application</source>
        <translation>Dodaj aplikaciju</translation>
    </message>
    <message>
        <source>Delete last added application</source>
        <translation type="vanished">Izbriši zadnju dodanu aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Border</source>
        <translation>Granica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Size</source>
        <translation>Veličina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>Select...</source>
        <translation>Odaberi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Background</source>
        <translation>Pozadina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Back</source>
        <translation>Nazad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>Select icon...</source>
        <translation>Izaberi ikonu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Dock Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>Display help </source>
        <translation>Prikaži pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>About this application</source>
        <translation>O ovoj aplikaciji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Quit application</source>
        <translation>Zatvori aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>black</source>
        <translation>crno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>white</source>
        <translation>bijelo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <source>Operation mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>&amp;Delete</source>
        <translation>&amp;Izbriši</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation type="vanished">&amp;Napravi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Dock name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="215"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Unesite ime za prikaz u Izborniku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Select dock to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Confirmation</source>
        <translation>Potvrda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Jeste li sigurni da želite izbrisati %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Otkaži</translation>
    </message>
    <message>
        <source>Delete last application</source>
        <translation type="vanished">Izbriši zadnju aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Delete this application</source>
        <translation>Izbriši ovu aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Save file</source>
        <translation>Spremi datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Dock saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>About %1</source>
        <translation>O programu %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Version: </source>
        <translation>Inačica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Description goes here</source>
        <translation>Opis ide ovdje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorska prava (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>%1 License</source>
        <translation>%1 Licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>%1 Help</source>
        <translation>%1 Pomoć</translation>
    </message>
    <message>
        <source>Please select a file.</source>
        <translation type="vanished">Molim odaberite datoteku.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>Select .desktop file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>Desktop Files (*.desktop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Select a dock file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>No file selected</source>
        <translation>Nijedna datoteka nije odabrana</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Could not open file</source>
        <translation>Ne mogu otvoriti datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Select dock to move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>Select icon</source>
        <translation>Izaberi ikonu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dijalog</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>Goresredina</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>Doljelijevo</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>Doljesredina</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>Gorelijevo</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>Goredesno</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>Doljedesno</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>Desnogore</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>Lijevogore</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>Lijevodolje</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>Desnodolje</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as normal user.</source>
        <translation>Morate pokrenuti ovaj program kao normalni korisnik.</translation>
    </message>
</context>
</TS>
